/*
 * Copyright (C) 2017-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import androidx.annotation.NonNull;

/**
 * Display information and instructions on what to do after a camera replacement.
 */
public class CameraSwapDetailsActivity extends Activity implements View.OnClickListener {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.camera_swap_details_activity);
        setInstructionsText();
        configureButtons();
    }

    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.button_got_it:
                onAcknowledgeCameraChanged(this);
                break;
            case R.id.button_remind_later:
                onRemindCameraChanged(this);
                break;

        }
        finish();
    }

    private void onAcknowledgeCameraChanged(@NonNull Context context) {
        Utils.handleAcknowledgeCameraChanged(context);
    }

    private void onRemindCameraChanged(@NonNull Context context) {
        Utils.handleRemindCameraChangedLater(context);
    }

    private void configureButtons() {
        Button mButtonGotIt = findViewById(R.id.button_got_it);
        mButtonGotIt.setOnClickListener(CameraSwapDetailsActivity.this);
        Button mButtonRemindLater = findViewById(R.id.button_remind_later);
        mButtonRemindLater.setOnClickListener(CameraSwapDetailsActivity.this);
    }

    private void setInstructionsText() {
        TextView titleView = findViewById(R.id.title);
        TextView part1View = findViewById(R.id.part1);

        int amountOfCameras = 1;

        if (!CameraSwapInfoPreferences.hasFrontCameraChanged(this)) {
            part1View.setText(getString(R.string.camera_swap_text_part1_main));
        } else if (!CameraSwapInfoPreferences.hasMainCameraChanged(this)) {
            part1View.setText(getString(R.string.camera_swap_text_part1_front));
        } else {
            amountOfCameras = 2;
            part1View.setText(getString(R.string.camera_swap_text_part1_both));
        }

        titleView.setText(getResources().getQuantityString(R.plurals.camera_swap_title, amountOfCameras));
    }
}
