/*
 * Copyright (C) 2017-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;

public class CameraSwapInfoPreferences {
    private static final String PREF_HAS_FRONT_CAMERA_CHANGED =
            "com.fairphone.cameraswapinfo.pref_has_front_camera_changed";
    private static final String PREF_HAS_MAIN_CAMERA_CHANGED =
            "com.fairphone.cameraswapinfo.pref_has_main_camera_changed";

    public static void setFrontCameraChanged(Context context, boolean hasChanged) {
        SharedPreferences preferenceManager =
                PreferenceManager.getDefaultSharedPreferences(context);
        preferenceManager.edit().putBoolean(PREF_HAS_FRONT_CAMERA_CHANGED, hasChanged).apply();
    }

    static boolean hasFrontCameraChanged(Context context) {
        SharedPreferences preferenceManager =
                PreferenceManager.getDefaultSharedPreferences(context);
        return preferenceManager.getBoolean(PREF_HAS_FRONT_CAMERA_CHANGED, false);
    }

    public static void setMainCameraChanged(Context context, boolean hasChanged) {
        SharedPreferences preferenceManager =
                PreferenceManager.getDefaultSharedPreferences(context);
        preferenceManager.edit().putBoolean(PREF_HAS_MAIN_CAMERA_CHANGED, hasChanged).apply();
    }

    static boolean hasMainCameraChanged(Context context) {
        SharedPreferences preferenceManager =
                PreferenceManager.getDefaultSharedPreferences(context);
        return preferenceManager.getBoolean(PREF_HAS_MAIN_CAMERA_CHANGED, false);
    }

    static int getAmountOfCamerasChanged(Context context) {
        SharedPreferences preferenceManager =
                PreferenceManager.getDefaultSharedPreferences(context);
        int amount = 0;

        if (preferenceManager.getBoolean(PREF_HAS_FRONT_CAMERA_CHANGED, false)) {
            amount += 1;
        }
        if (preferenceManager.getBoolean(PREF_HAS_MAIN_CAMERA_CHANGED, false)) {
            amount += 1;
        }

        return amount;
    }
}
