/*
 * Copyright (C) 2017-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.core.app.NotificationCompat;

public class CameraSwapNotificationUtil {

    private static final int NOTIFICATION_ID = 0;

    public static void showNotification(@NonNull Context context) {
        Notification notification = getNotification(context);
        getNotificationManager(context).notify(NOTIFICATION_ID, notification);
    }

    static void destroyNotification(@NonNull Context context) {
        getNotificationManager(context).cancel(NOTIFICATION_ID);
    }

    static private Notification getNotification(Context context) {
        int amountOfCameras = CameraSwapInfoPreferences.getAmountOfCamerasChanged(context);

        PendingIntent openIntent = getPendingIntent(context);
        String channelId = context.getString(R.string.notification_channel_id);
        NotificationCompat.Builder mBuilder =
                new NotificationCompat.Builder(context, channelId)
                        .setSmallIcon(R.drawable.ic_stat_camera_swap)
                        .setContentTitle(getNotificationTitle(context, amountOfCameras))
                        .setContentText(getNotificationShortSummary(context, amountOfCameras))
                        .setStyle(new NotificationCompat.BigTextStyle().bigText(
                                getNotificationExtendedSummary(context, amountOfCameras)))
                        .setColor(context.getResources().getColor(R.color.colorPrimary))
                        .setPriority(NotificationCompat.PRIORITY_MAX)
                        .setVisibility(NotificationCompat.VISIBILITY_PUBLIC)
                        .setContentIntent(openIntent)
                        .setOngoing(true);
        return mBuilder.build();
    }

    static void createNotificationChannel(@NonNull Context context) {
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
            return;
        }
        String channelId = context.getString(R.string.notification_channel_id);
        String name = context.getString(R.string.notification_channel_name);
        NotificationChannel channel = new NotificationChannel(
                channelId,
                name,
                NotificationManager.IMPORTANCE_HIGH
        );
        getNotificationManager(context).createNotificationChannel(channel);
    }

    private static String getNotificationTitle(Context context, int amountOfCameras) {
        return context.getString(R.string.camera_swap_notification_title);
    }

    private static String getNotificationShortSummary(Context context, int amountOfCameras) {
        return context.getResources().getQuantityString(R.plurals.camera_swap_notification_summary, amountOfCameras);
    }

    private static String getNotificationExtendedSummary(Context context, int amountOfCameras) {
        return context.getResources().getQuantityString(R.plurals.camera_swap_notification_summary, amountOfCameras)
                + " " + context.getResources().getQuantityString(R.plurals.camera_swap_notification_text, amountOfCameras);
    }

    private static PendingIntent getPendingIntent(Context context) {
        return PendingIntent.getActivity(context, 0,
                new Intent(context, CameraSwapDetailsActivity.class)
                        .setFlags(Intent.FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS | Intent.FLAG_ACTIVITY_NEW_TASK),
                PendingIntent.FLAG_UPDATE_CURRENT);
    }

    private static NotificationManager getNotificationManager(@NonNull Context context) {
        return (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);
    }
}
