/*
 * Copyright (C) 2020-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo;

import android.content.Context;
import android.util.Log;

import com.fairphone.cameraswapinfo.receivers.BootUpReceiver;
import com.fairphone.cameraswapinfo.workers.WorkerUtils;

import androidx.annotation.NonNull;

public class Utils {

    private static final String TAG = "CameraSwapInfo";

    public static final String EXTRA_FRONT_CAMERA_CHANGED =
            "com.fairphone.moduledetect.EXTRA_FRONT_CAMERA_CHANGED";

    public static final String EXTRA_REAR_CAMERA_CHANGED =
            "com.fairphone.moduledetect.EXTRA_REAR_CAMERA_CHANGED";

    public static void handleCameraChanged(@NonNull Context context) {
        boolean hasFrontCameraChanged = CameraSwapInfoPreferences.hasFrontCameraChanged(context);
        boolean hasRearCameraChanged = CameraSwapInfoPreferences.hasMainCameraChanged(context);
        handleCameraChanged(context, hasFrontCameraChanged, hasRearCameraChanged);
    }

    public static void handleCameraChanged(
            @NonNull Context context,
            boolean hasFrontCameraChanged,
            boolean hasRearCameraChanged
    ) {
        if (!hasFrontCameraChanged && !hasRearCameraChanged) {
            Log.d(TAG, "No change of camera detected, ignoring");
            return;
        }
        /* persist the changed cameras */
        CameraSwapInfoPreferences.setFrontCameraChanged(context, hasFrontCameraChanged);
        CameraSwapInfoPreferences.setMainCameraChanged(context, hasRearCameraChanged);

        /* we have to be able to remind user on next boot */
        BootUpReceiver.enable(context);
        CameraSwapNotificationUtil.showNotification(context);
    }

    static void handleAcknowledgeCameraChanged(@NonNull Context context) {
        CameraSwapNotificationUtil.destroyNotification(context);

        // The camera change is complete
        CameraSwapInfoPreferences.setFrontCameraChanged(context, false);
        CameraSwapInfoPreferences.setMainCameraChanged(context, false);

        // We do not need to remind the user on the next boot
        BootUpReceiver.disable(context);

        Log.d(TAG, "Acknowledged the camera change");
    }

    static void handleRemindCameraChangedLater(@NonNull Context context) {
        boolean hasFrontCameraChanged = CameraSwapInfoPreferences.hasFrontCameraChanged(context);
        boolean hasRearCameraChanged = CameraSwapInfoPreferences.hasMainCameraChanged(context);
        CameraSwapNotificationUtil.destroyNotification(context);
        setReminder(context, hasFrontCameraChanged, hasRearCameraChanged);
    }

    private static void setReminder(
            @NonNull Context context,
            boolean hasFrontCameraChanged,
            boolean hasRearCameraChanged
    ) {
        WorkerUtils.startActionCameraChangedWithDelay(
                context,
                hasFrontCameraChanged,
                hasRearCameraChanged);
    }
}
