/*
 * Copyright (C) 2020-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo.receivers;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

import com.fairphone.cameraswapinfo.Utils;

public class CameraSwapBroadcastReceiver extends BroadcastReceiver {

    /**
     * Action to handle a change of camera(s).
     */
    public static final String ACTION_HANDLE_CAMERA_CHANGED =
            "com.fairphone.moduledetect.ACTION_HANDLE_CAMERA_CHANGED";

    public static final String PERM_HANDLE_CAMERA_CHANGED =
            "com.fairphone.cameraswapinfo.permission.HANDLE_CAMERA_CHANGED";

    @Override
    public void onReceive(Context context, Intent intent) {
        if (!ACTION_HANDLE_CAMERA_CHANGED.equals(intent.getAction())) {
            return;
        }
        processIntent(context, intent);
    }

    private void processIntent(Context context, Intent intent) {
        boolean hasFrontCameraChanged = intent.getBooleanExtra(Utils.EXTRA_FRONT_CAMERA_CHANGED, false);
        boolean hasRearCameraChanged = intent.getBooleanExtra(Utils.EXTRA_REAR_CAMERA_CHANGED, false);
        Utils.handleCameraChanged(context, hasFrontCameraChanged, hasRearCameraChanged);
    }
}
