/*
 * Copyright (C) 2020-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo.workers;

import android.content.Context;

import com.fairphone.cameraswapinfo.Utils;

import androidx.annotation.NonNull;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

public class CameraSwapNotificationWorker extends Worker {

    public CameraSwapNotificationWorker(
            @NonNull Context context,
            @NonNull WorkerParameters workerParams
    ) {
        super(context, workerParams);
    }

    @NonNull
    @Override
    public Result doWork() {
        boolean hasFrontCameraChanged = hasFrontCameraChanged();
        boolean hasRearCameraChanged = hasRearCameraChanged();
        Utils.handleCameraChanged(
                getApplicationContext(),
                hasFrontCameraChanged,
                hasRearCameraChanged
        );

        return Result.success();
    }

    private boolean hasFrontCameraChanged() {
        return getInputData().getBoolean(Utils.EXTRA_FRONT_CAMERA_CHANGED, false);
    }

    private boolean hasRearCameraChanged() {
        return getInputData().getBoolean(Utils.EXTRA_REAR_CAMERA_CHANGED, false);
    }
}
