/*
 * Copyright (C) 2020-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.fairphone.cameraswapinfo.workers;

import android.content.Context;

import java.util.concurrent.TimeUnit;

import androidx.annotation.NonNull;
import androidx.work.Data;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;
import androidx.work.WorkRequest;

import com.fairphone.cameraswapinfo.Utils;

public class WorkerUtils {

    /**
     * Grace period before firing a reminder (in milliseconds): 1 day.
     */
    private static final long REMINDER_GRACE_PERIOD_MS = 1000 * 60 * 60 * 24;

    public static void startActionCameraChangedWithDelay(
            @NonNull Context context,
            boolean hasFrontCameraChanged,
            boolean hasRearCameraChanged
    ) {
        Data extras = new Data.Builder()
                .putBoolean(Utils.EXTRA_FRONT_CAMERA_CHANGED, hasFrontCameraChanged)
                .putBoolean(Utils.EXTRA_REAR_CAMERA_CHANGED, hasRearCameraChanged)
                .build();
        WorkRequest workRequest = new OneTimeWorkRequest.Builder(CameraSwapNotificationWorker.class)
                .setInputData(extras)
                .setInitialDelay(REMINDER_GRACE_PERIOD_MS, TimeUnit.MILLISECONDS)
                .build();
        WorkManager.getInstance(context).enqueue(workRequest);
    }
}
